"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startSandbox = exports.addStartSandboxCommand = void 0;
const console_1 = require("../../console");
const bundle_1 = require("../../modules/bundle");
const flextesa_1 = require("../../modules/flextesa");
const addStartSandboxCommand = (program, debugHook) => {
    program
        .command('start-sandbox')
        .description('Create a local Flextesa Tezos test network.')
        .option('-h, --host <host>', 'Sandbox hostname')
        .option('-p, --port <port>', 'Sandbox port')
        .option('-P, --protocol <protocol>', 'What Tezos protocol will this Sanbox run')
        .option('-g, --genesis-block', 'The first block to start the Sandbox with')
        .action((options) => {
        (0, exports.startSandbox)(options);
    })
        .hook('preAction', debugHook);
};
exports.addStartSandboxCommand = addStartSandboxCommand;
// Full start-sandbox command controller
const startSandbox = async (options, readyCallback) => {
    (0, console_1.em)(`Starting Tezos sandbox...\n`);
    // Read configfile
    const contractsBundle = new bundle_1.ContractsBundle((0, console_1.getCWD)());
    const config = await contractsBundle.readConfigFile();
    // Build final options
    const flextesaOptions = Object.assign({}, config.sandbox, options);
    (0, flextesa_1.startFlextesa)(flextesaOptions, readyCallback);
};
exports.startSandbox = startSandbox;
