import { LIGOFlavors, LIGOVersion } from "../ligo";
import { FaucetAccount, TezosProtocols } from "../tezos";
export declare enum ToolchainNetworks {
    SANDBOX = "sandbox",
    TESTNET = "testnet",
    MAINNET = "mainnet"
}
export declare type Config = {
    repoName: string;
    ligoVersion: LIGOVersion;
    preferredLigoFlavor: LIGOFlavors;
    autoCompile: boolean;
    autoSandbox: boolean;
    sandbox: {
        host: string;
        port: number;
        protocol: TezosProtocols;
        genesisBlockHash: string;
        accounts: {
            [accountName: string]: {
                pkh: string;
                sk: string;
                pk: string;
            };
        };
    };
    /**
     * Newtork settings
     *
     * These settings make up three aliases for the network you'll probably need while developing a
     * smart contract on Tezos:
     * - sandbox:   the local sandboxed network used to run unit tests and to test contract deploying
     * - testnet:   the remote test network you can use to run (unit or) e2e tests and to deploy contract and test integration with your app
     * - mainnet:   the public node of the real Tezos network, used only to deploy the finished contract
     */
    networks: {
        [ToolchainNetworks.SANDBOX]: {
            defaultSignerSK: string;
        };
        [ToolchainNetworks.TESTNET]: {
            host: string;
            port: number;
            faucet: null | FaucetAccount;
        };
        [ToolchainNetworks.MAINNET]: {
            host: string;
            port: number;
        };
    };
    contractsDirectory: string;
    outputDirectory: string;
};
